//This dofile creates the 1970 base shares (by commuting zone) for use in constructing the Card IV. The end data set is immdist70cz. 


cd "C:\Data" 


clear 
set more off




******************************************************************************************************************************
**1. Create Commuting Zones from the 1970 County groups
******************************************************************************************************************************

/*I start with the 1970 data. This includes both metro samples (but none of the others)*/

use usa_00063_1970, clear 

	
/**I have the two metro samples because county groups are only in the metro samples (vs. the state samples) and that's 
what we use to create commuting zones. Because I'm using two one percent samples for 1970 and weights are constructed to scale 
each data set up to the population on its own, I have to adjust the weights. */ 
 

g perwt70=perwt/2


***David Dorn's crosswalk has a different variable name for the county group so I constructed a new varaible with David's variable name

g ctygrp1970=cntygp97

*count:  4,059,942

save temp_1970, replace 


/**The cross walk for county group to commuting zones was found here "http://www.ddorn.net/data.htm" on 1/16/16"; it is labeled E2 
on the webpage. I downloaded it into the "CommutingZones folder" and unzipped before running this. The crosswalk is called cw_ctygrp1970_czone.zip.*/

use  "C:\Dropbox\Elderly\JHR replication files\Data\CommutingZones\cw_ctygrp1970_czone.dta", clear 
	
	joinby  ctygrp1970 using temp_1970

/**Check for accuracy: do the afactors sum to one? : 

bysort datanum serial pernum: egen testsum2=total(afactor)
sum testsum2, detail
drop testsum2 

Yes, they sum to one (up to rounding error). Caution: Because we merged two data sets, 
be sure to use datanum along with serial and person number to identify individuals*/ 	
	
	
//This new weight is used to address the issue that some country groups cross commuting zone lines. 

	g a_perwt=afactor*perwt70



save metvarsCZ_1970, replace  




******************************************************************************************************************************
**2. Create the share of each origin country that is in each commuting zone (Base "pull factors" for Card IV)
******************************************************************************************************************************

keep czone bpl a_perwt 

*Keep only immigrants 
drop if bpl<100


***a) Aggregate the BPLs using the Gaetano Basso crosswalk*******

do "C:\Dropbox\Elderly\JHR replication files\BPLaggregation.do"   //Groups origin countries into 16 different categories. The new BPL measures is called BPLGROUP (BPLG for short). 

g x=1


save temp_1970, replace  



**b) Create counts by country of origin and czone, ie hte number of people from each origin that are in each commuting zone 


collapse (count) num_bplcz=x [pw=a_perwt], by(bplg czone) 

save temp_bplcz, replace


**c) Create counts by country of origin 

use temp_1970, clear 

collapse (count) num_bpl=x [pw=a_perwt], by(bplg) 

save temp_bpl, replace


**d) Merge and create the share variable! 

use temp_bplcz, clear 

merge m:1 bplg using temp_bpl

drop _merge 

g share_bplcz1970=num_bplcz/num_bpl

save immdist70cz , replace


*count: N=9425
*There are 16 distinct bplgroups and 741 czones but there are some bplgroups that are not in some czones since 741*16=11,856 >9425.


/*Cross-check the data: 

Do the shares of each origin group across different commuting zones sum to one? Yes. 

bysort bplgroup: egen totbpl=total(share)
sum totbpl  //confirm this is all 1's 
drop totbpl */ 



erase temp_1970.dta 
erase temp_bplcz.dta 
erase temp_bpl.dta
