//Constructing Variables from 2000 Census and 2005 & 2010 ACS Data //

/*This dofile constructs commuting zones andd all of the commuting zone-year level variables from the Census/ACS data, 
including the number of immigrants, share of the commuting zone population that is over age 65, the nursing labor market variables, etc. 
The end data set is CardIV_levs_CZ. */ 


*Change directory 

cd "C:\Data" 


clear 

set more off

******************************************************************************************************************************
*1. Put everyone into commuting zones 
******************************************************************************************************************************

*a) Put the 2000, 2005, 2010 data together 

use ACS2005_2017, clear 

keep if year==2005 | year==2010

append using ipums_2000 //Append with the 2000 data 

cd "C:\data" 

*b) Create the "puma" variable which can be merged with the David Dorn crosswalk 

g puma2000=real(string(statefip)+string(puma, "%04.0f")) //Notice: pumas have up to four digits starting in 2012. Hence the 4. 
replace puma2000=221801 if puma2000==2277777  //See the notes (https://usa.ipums.org/usa-action/variables/PUMA#comparability_section) for how New Orleans PUMAs are dealt with. All three pumas are in the same CZ so I arbitrarily assigned them to one. 

save temp_2000_2005_2010cz, replace
*N=20,021,538

*c) Use the Dorn crosswalk 

**This is the transition matrix provided on David Dorn's webpage 	

use "C:\Dropbox\Elderly\JHR replication files\Data\CommutingZones\cw_puma2000_czone.dta", clear 
	
joinby puma2000 using temp_2000_2005_2010cz  
	
g a_perwt=afactor*perwt
	
save temp_2000_2005_2010cz, replace //This new weight is used to address the issue that some pumas cross commuting zones. See note in dofile 1_Make_IV1970

*N=30,114,006


	
******************************************************************************************************************************
*2. Create  variables 
******************************************************************************************************************************

*a) Basic demographic*********

*Foreign-born
gen immig=(bpl>100)

*Gender
gen female=(sex==2)

*Education
gen col=(educ>=10 & educ<=11)
replace col=. if age<25


*Age distribution
g age65p=(age>=65)  //age 65plus

**Race
g black=(race==2)
g hisp=(hispan>0)
**I didn't make these mutually exclusive


*b) Work-related variabes******

**In labor force (of those above age 16). Empstat: 1 is employed, 2 is unemployed, 3 is not in labor force, and 0 is N/A--meaning under age 16).

gen lf=(empstat==1 | empstat==2)  //either employed or unemployed
replace lf=. if empstat==0  //not in universe, meaning under age 16

g unemp=(empstat==2)
replace unemp=. if empstat==0 | empstat==3  //sets to missing those that are under 16 or not in labor force 

**Weeks worked was a continuous variable, called wkswork1 in 2000 but categorical in ACS. I took the midpoint in ACS. */


g wkswork=6.5 if wkswork2==1 
replace wkswork=20 if wkswork2==2 
replace wkswork=33  if wkswork2==3  
replace wkswork=43.5 if wkswork2==4 
replace wkswork=48.5 if wkswork2==5 
replace wkswork=51  if wkswork2==6 


replace wkswork=wkswork1 if year==2000


** Hours worked 

g tothrs=wkswork*uhrswork

**Make hourly wage: We didn't end up using  

gen double wage=incwage/(wkswork*uhrswork)
replace wage=. if wkswork==0 | uhrswork==0 | incwage==0 |empstat==0| empstat==2

**Generate wages and employment in specific occupations/industries 

g nursewage=wage if occ1990==447 | occ1990==95 | occ1990==207  //nursing assistants, RNs, LPNs
g RNwage=wage if occ1990==95  //RN
g LPNwage=wage if occ1990==207  //LPN
g NAwage=wage if occ1990==447  //Nursing assistant

**Next, I look at just those that work specifically in the nursing home industry 

g NHindwage=wage if ind1990==832
g NH_RNwage=wage if ind1990==832 & occ1990==95
g NH_LPNwage=wage if ind1990==832  & occ1990==207
g NH_NAwage=wage if ind1990==832  & occ1990==447

g NH_notnursewage=wage if ind1990==832 & occ1990~=95 & occ1990~=207 & occ1990~=447


**Now, make dummies for these to look at employment shares in relevant occupations**

g nurse=(occ1990==447 | occ1990==95 | occ1990==207)  //nursing assistants, RNs, LPNs
replace nurse=. if wkswork==0 | uhrswork==0 | incwage==0 |empstat==0| empstat==2

g RN=(occ1990==95)   //RN
replace RN=. if wkswork==0 | uhrswork==0 | incwage==0 |empstat==0| empstat==2

g LPN=(occ1990==207)  //LPN
replace LPN=. if wkswork==0 | uhrswork==0 | incwage==0 |empstat==0| empstat==2

g NA=(occ1990==447)  //Nursing assistant
replace NA=. if wkswork==0 | uhrswork==0 | incwage==0 |empstat==0| empstat==2

**Next, I look at just those that work specifically in the nursing home industry 

g NHind=(ind1990==832)
replace NHind=. if wkswork==0 | uhrswork==0 | incwage==0 |empstat==0| empstat==2

g NH_RN=(ind1990==832 & occ1990==95)
replace NH_RN=. if wkswork==0 | uhrswork==0 | incwage==0 |empstat==0| empstat==2

g NH_LPN=(ind1990==832  & occ1990==207)
replace NH_LPN=. if wkswork==0 | uhrswork==0 | incwage==0 |empstat==0| empstat==2

g NH_NA=(ind1990==832  & occ1990==447)
replace NH_NA=. if wkswork==0 | uhrswork==0 | incwage==0 |empstat==0| empstat==2

g NH_notnurse=(ind1990==832 & occ1990~=95 & occ1990~=207 & occ1990~=447)
replace NH_notnurse=. if wkswork==0 | uhrswork==0 | incwage==0 |empstat==0| empstat==2 
	
	
	
	
***Other occupations (added Jan 10, 2023) 


g funeral=(occ1990==19)   //Funeral Director 
replace funeral=. if wkswork==0 | uhrswork==0 | incwage==0 |empstat==0| empstat==2

g LawEnforc=(occ1990==423)  //Other law enforcement (sheriff, etc.) 
replace LawEnforc=. if wkswork==0 | uhrswork==0 | incwage==0 |empstat==0| empstat==2

g dentist=(occ1990==85)  //Laywer
replace dentist =. if wkswork==0 | uhrswork==0 | incwage==0 |empstat==0| empstat==2


	
	
	
	
	
foreach X in nurse RN LPN NA{
		g uhrs_`X'=uhrswork if `X'==1
		replace uhrs_`X'=. if uhrswork==0
		g uhrsWzeros_`X'=uhrswork if `X'==1
		g tothrs_`X'=tothrs if `X'==1
		g fb_`X'=(`X'==1)*(bpld>=10000)
		}
		
g tothrs_imm=tothrs*(bpld>=10000) 	
	
	

**indicator variable. I will use this to who number of observations in each CZ 
g x=1


save temp_20151120, replace



***************************************************************************
/***Create a dummy for if people have an occupation with very few immigrants*/
***************************************************************************

*8tep 1: Create the percent immigrant in each occupation using 2000, 2005, 2010 data (which we use in teh analysis) 

gcollapse (mean) perFBocc=immig [pw=a_perwt], by(occ1990)

save perFBocc, replace 

*Step 2: Merge back into our data 

use temp_20151120, clear 

merge m:1 occ1990 using perFBocc

drop _merge

*drop if occ1990>=991  //confirm no other missing data for this occupation vairable 

*Step 3: Find percentiles and create new dummies 

summarize perFBocc [aw=a_perwt] if occ1990<991, detail 

display r(p1)

foreach num of numlist 1  {
	gen perFBocc`num'= (perFBocc<=r(p`num'))
	replace perFBocc`num'=. if wkswork==0 | uhrswork==0 | incwage==0 |empstat==0| empstat==2
	}

*************************************************
 



******************************************************************************************************************************
*3. Create the aggregate data at the commuting zone - year level 
******************************************************************************************************************************

gcollapse (mean) pimm=immig   pcol=col  page65p=age65p /*
	*/ pfemale=female pblack=black phispan=hisp punemp=unemp nursewage RNwage LPNwage NAwage nurse RN LPN NA NH*  /*
	*/ cz_uhrs_nurse=uhrs_nurse cz_uhrs_RN=uhrs_RN cz_uhrs_LPN=uhrs_LPN cz_uhrs_NA=uhrs_NA /*
	*/cz_uhrsWzeros_RN=uhrsWzeros_RN cz_uhrsWzeros_LPN=uhrsWzeros_LPN cz_uhrsWzeros_NA=uhrsWzeros_NA /*	
	*/(median) wage_p50=wage med_nursewage=nursewage med_RNwage=RNwage med_LPNwage=LPNwage med_NAwage=NAwage med_NAindwage=NHindwage med_NH_RNwage=NH_RNwage med_NH_LPNwage=NH_LPNwage med_NH_NAwage=NH_NAwage med_NH_notnurse=NH_notnurse  /*
	*/ (p25) cz_p25_NA=NAwage cz_p25_LPN=LPNwage cz_p25_RN=RNwage (p50) cz_p50_NA=NAwage cz_p50_LPN=LPNwage cz_p50_RN=RNwage (p75) cz_p75_NA=NAwage cz_p75_LPN=LPNwage cz_p75_RN=RNwage /*
	*/ (rawsum) numobs=x /*
	*/(sum) pop_ipums=x num_imms=immig cz_Nimmig=immig  cz_poptot=x  cz_N_nurse=nurse cz_N_RN=RN cz_N_LPN=LPN cz_N_NA=NA cz_N_funeral=funeral cz_N_LawEnforc=LawEnforc /*
	*/  N_perFBocc1=perFBocc1  /* Number of people in occupations with few immigrants  (bottom 1 percent) 
	*/ cz_tothrs_RN=tothrs_RN  cz_tothrs_LPN=tothrs_LPN cz_tothrs_NA=tothrs_NA cz_tothrs=tothrs cz_tothrs_imm=tothrs_imm cz_Nfb_nurse=fb_nurse cz_Nfb_RN=fb_RN cz_Nfb_LPN=fb_LPN cz_Nfb_NA=fb_NA /*
	*/ cz_totNHind=NHind cz_totNH_RN=NH_RN cz_totNH_LPN=NH_LPN cz_totNH_NA=NH_NA cz_totNH_notnurse=NH_notnurse /*
	*/ [pw=a_perwt], by(czone year)
	
	
	save CZdata, replace  //CZ- YEAR level data


*N= 2,223  =741 CZs x 3 years, no mising CZs. 


******************************************************************************************************************************
*4. Counts of immigrants to be used to make the IV 
******************************************************************************************************************************

use temp_20151120, clear

*a) Aggregate the birth countries (BPL) into 16 origin 'countries' using the Gaetano Basso crosswalk*******

do "C:\Dropbox\Elderly\JHR replication files\BPLaggregation.do"   //Groups origin countries into 16 different categories. The new BPL measures is called BPLGROUP (BPLG for short). 


drop if bplgroup==.

gcollapse (count) N_bplgroup=x   [pw=a_perwt], by(bplgroup year)   
cd "C:\data" //Delia's desktop 


save BPLcountdata, replace   //Country of origin level-YEAR data 


******************************************************************************************************************************
*5. Merge in the 1970 distribution data and create the IV 
******************************************************************************************************************************

*a) Merge the 1970 share "pull factor" data created in dofile 2_StartCardIV1970.do with the yearly count day by origiin country. 


use immdist70cz, clear //

joinby using BPLcountdata, unmatched(both)  //merging variables (that appear in both data sets): bpl year. 

*tab _merge //perfect match 
*drop _merge
*N=28,275 

*b)  Create the IV origin-specific components (predicted number of each origin country in each commuting zone each year 

/*NOTE: For each country of origin/commuting zone, this next variable multiplies the number of observations from the origin country in the entire US 
in that year with the 1970 share foreign born from that country of origin in the czone.*/

g pred70immC=share_bplcz1970*N_bplgroup


*c)  Sum over all of the origins within each czone-year 

collapse (sum) inst1_70_levs_CZ=pred70immC, by(czone year) 

save Inst1_70dataCZ, replace 

*N=2,223


******************************************************************************************************************************
*6. Merge in ommuting zone - year level data created in step 3 above: Number foreign born, etc.  
******************************************************************************************************************************

merge 1:1 czone year using CZdata.dta

**Perfect merge! 

drop _merge 


save CardIV_levs_CZ, replace 

******************************************************************************************************************************
*7. Erase temporary data files that we will no longer use (this isn't necesary)   
******************************************************************************************************************************



erase temp_20151120.dta 
erase BPLcountdata.dta 




