/* Constructs Stata data sets for each year of available LTCFocus data, downloaded at the county level. Counties are  placed into commuting zones using the crosswalk 
available on David Dorn’s website and provided by us in the data folder. End data set,  LTCcty2000_2019,  contains all years of LTCFocus data, but we only use
data from 2000, 2005, and 2010 in the paper. */ 

******************************************************************************************************************************
*1. Create Stata files from the Excel files downloaded from the LTCFocus website. 
******************************************************************************************************************************


foreach num of numlist 2000/2010 {
	cd "C:\Dropbox\Elderly\JHR replication files\Data\LTCFocusData" 
	import excel county`num'.xls, firstrow clear
	cd "C:\Data" 

	save county`num', replace
	}

foreach num of numlist 2011/2016 {
	cd "C:\Dropbox\Elderly\JHR replication files\Data\LTCFocusData" 
	import excel county_`num'.xls, firstrow clear
	cd "C:\Data" 
	save county`num', replace
	}
	
foreach num of numlist 2017/2018 {
	cd "C:\Dropbox\Elderly\JHR replication files\Data\LTCFocusData" 
	import delimited county_`num'.csv,  clear
	cd "C:\Data" 
	g str3 county_s=string(county,"%03.0f")
	drop county 
	rename county_s county
	save county`num', replace
	}
	
cd "C:\Dropbox\Elderly\JHR replication files\Data\LTCFocusData" 

import delimited county_2019_MDS.csv,  clear
	cd "C:\Data" 
	g str3 county_s=string(county,"%03.0f")
	drop county 
	rename county_s county
	save county2019, replace
	

******************************************************************************************************************************
*2. Merge the LTCFocus data with David Dorn cross-walk to get commuting zone 
******************************************************************************************************************************

/**Note: The LTCFocus data lists state with a 2 letter abbrevation and county with a 3 digit number. To use the David Dorn's crosswalk 
between county and commuting zone, we need to form a 5 digit county code, with first two digits representing the state.

My RA found a crosswalk between state abbreviations (2 letters) and digit fips codes (2 numbers) which I have saved as StateFIPS. This is merged with the LTCFocus 
below before using the crosswalk for putting counties into commuting zones. */ 
 

foreach num of numlist 2000/2019 { 
	use county`num', clear 
	merge m:1 state using "C:\Dropbox\Elderly\JHR replication files\Data\LTCFocusData\StateFIPS.dta"   //to get the two digit fips code for each state 
	drop if _m==2  //examples include DC, AK, PR, VI in 2015 (no counties with nursng homes in those states in those years) 
	drop _merge

	gen state_fips = string(fips) //form a string from the numeric fips code 

	gen cty_fips_s = state_fips+ county  //put the state and county digits together 

	gen cty_fips = real(cty_fips_s)  //make it numeric 
	drop cty_fips_s state_fips
	
	replace cty_fips=12025 if cty_fips==12086 //In 1997, Dade county (FIPS 12025) renamed Miami-Dade (ctyFIPS 12086_ so just replace 12086 with 12025)
	save county`num', replace


	merge m:1 cty_fips using "C:\Dropbox\Elderly\JHR replication files\Data\CommutingZones\cw_cty_czone.dta"
	replace czone=28900 if cty_fips==8014  //Broomfield county (FIPS 8014) created out of several parts of other counties but most from Boulder so give it bolder's CZ=28900
	
	drop if _m==2
	
	**NOTE: the changes I made above to specific counties were driven by notes on David Dorn's website: "https://www.ddorn.net/data/FIPS_County_Code_Changes.pdf" 
	
	drop _merge 

	save county`num', replace  
	}
	
	

******************************************************************************************************************************
*3.  Create numeric variables from string variables in the LTC focus data, also added a "year" varaible  
******************************************************************************************************************************

foreach num of numlist 2000/2005 {

	*Create a variable to show the year
	use county`num', clear 	
	g year=`num'
	
	
	*Make the string variables numeric
	foreach var of varlist avgrugcmi_cty- la_herfbeds_cty {

		g r_`var'=real(`var')  //created numeric from string 
		drop `var'
		rename r_`var' `var'  //transferred back to the original variable name 
	 }
	 
	 save LTCctydata`num', replace 
}


	 

*Starting in 2006, the LTC added some new variables and so needed adjustments to the code 
	 
	 
foreach num of numlist 2006/2010 {

	*Create a variable to show the year
	use county`num', clear 	
	g year=`num'
	
	
	*Make the string variables numeric
	foreach var of varlist nhcpain_cty- la_herfbeds_cty {

		g r_`var'=real(`var')  //created numeric from string 
		drop `var'
		rename r_`var' `var'  //transferred back to the original variable name 
	 }
	 
	 save LTCctydata`num', replace 
}


	 
foreach num of numlist 2011/2014 {

	*Create a variable to show the year
	use county`num', clear 	
	
	*Make the string variables numeric
	foreach var of varlist totbeds_cty- mds_hospptyr_cty {

		g r_`var'=real(`var')  //created numeric from string 
		drop `var'
		rename r_`var' `var'  //transferred back to the original variable name 
	 }
	 
	 save LTCctydata`num', replace 
}

	 
foreach num of numlist 2015/2016 {

	*Create a variable to show the year
	use county`num', clear 	
	
	*Make the string variables numeric
	foreach var of varlist totbeds_cty- PctPvtDays_cty {

		g r_`var'=real(`var')  //created numeric from string 
		drop `var'
		rename r_`var' `var'  //transferred back to the original variable name 
	 }
	 
	 save LTCctydata`num', replace 
}

foreach num of numlist 2017/2018 {

	*Create a variable to show the year
	use county`num', clear 	
	
	*Make the string variables numeric
	foreach var of varlist nresid_cty agg_cmi_mds3_cty- pctobese_cty mds_hospptyr_cty avg_dailycensus_cty {

		g r_`var'=real(`var')  //created numeric from string 
		drop `var'
		rename r_`var' `var'  //transferred back to the original variable name 
	 }
	 
	 save LTCctydata`num', replace 
}

foreach num of numlist 2019 {

	*Create a variable to show the year
	use county`num', clear 	
	
	*Make the string variables numeric
	foreach var of varlist nresid_cty- pctobese_cty mds_hospptyr_cty  avg_dailycensus_cty{

		g r_`var'=real(`var')  //created numeric from string 
		drop `var'
		rename r_`var' `var'  //transferred back to the original variable name 
	 }
	 
	 save LTCctydata`num', replace 
}

	 
	 
******************************************************************************************************************************
*4. Append all of the years of data together and add a variable linking a state to each czone
******************************************************************************************************************************

*a) Append data together 
use LTCctydata2000, clear

append using  LTCctydata2001 LTCctydata2002 LTCctydata2003 LTCctydata2004 LTCctydata2005 LTCctydata2006 LTCctydata2007 LTCctydata2008 /* 
	*/ LTCctydata2009 LTCctydata2010 LTCctydata2011 LTCctydata2012 LTCctydata2013 LTCctydata2014 LTCctydata2015 LTCctydata2016 /*
	*/  LTCctydata2017 LTCctydata2018 LTCctydata2019, force  
	
	
*b) This merges in David Dorn's crosswalk for CZ and state. (David Dorn assigned the most likely state to CZs that cross state boarder, based on populatoin(

merge m:1 czone using "C:\Dropbox\Elderly\JHR replication files\Data\CommutingZones\cw_czone_state.dta" 
drop if _m==2  //there were 23 in David Dorn's data with no matches, most probably b/c no nursing homes in these CZs (15 in Alaska 3 in SD, the rest in OR, TX, UT.) 
drop _merge 

	
save LTCcty2000_2019, replace 


erase LTCctydata2000.dta 
erase LTCctydata2001.dta  
erase LTCctydata2002.dta 

erase LTCctydata2003.dta 
erase LTCctydata2004.dta 
erase LTCctydata2005.dta 


erase LTCctydata2006.dta 
erase LTCctydata2007.dta 
erase LTCctydata2008.dta 

erase LTCctydata2009.dta 
erase LTCctydata2010.dta 
erase LTCctydata2011.dta 

erase LTCctydata2012.dta 
erase LTCctydata2013.dta 
erase LTCctydata2014.dta 

erase LTCctydata2015.dta 
erase LTCctydata2016.dta 

erase LTCctydata2017.dta 
erase LTCctydata2018.dta 
erase LTCctydata2019.dta 

